# Latice - Jeu Physique en Java

**Latice** est une recréation du jeu physique **Latice** en utilisant **Java** et **JavaFX**. Ce jeu vous permet de manipuler des objets physiques à l'écran, en interagissant avec des éléments comme des obstacles et des forces pour résoudre des puzzles. Le but est de déplacer et de faire interagir des éléments dans un environnement simulé.

## Table des matières

- [Introduction](#introduction)
- [Fonctionnalités](#fonctionnalités)
- [Installation](#installation)
- [Utilisation](#utilisation)
- [Technologies utilisées](#technologies-utilisées)
- [Contribuer](#contribuer)
- [License](#license)

---

## Introduction

Latice est un jeu physique où vous pouvez déplacer des objets dans un environnement en 2D, appliquer des forces et interagir avec des obstacles pour atteindre un objectif. Le jeu a été développé en **Java** avec la bibliothèque **JavaFX** pour l'interface graphique, afin de fournir une expérience fluide et interactive.

Le jeu reprend les concepts du jeu physique classique tout en les adaptant à une interface moderne et intuitive sur PC.

---

## Fonctionnalités

- **Interface graphique fluide** : Créez et manipulez des objets avec une interface utilisateur simple et claire.
- **Simulation physique réaliste** : Utilise les lois de la physique pour simuler les mouvements des objets.
- **Niveaux de difficulté** : Plusieurs niveaux et défis à résoudre, avec des obstacles et des objets interactifs.
- **Animation et interactions en temps réel** : Observez les objets réagir aux forces et collisions en temps réel.
- **Contrôle intuitif** : Déplacement des objets avec la souris et manipulation des forces appliquées sur ceux-ci.

---

## Installation

### Prérequis

Avant d'installer Latice, vous devez avoir **Java** et **JavaFX** installés sur votre machine. Assurez-vous d'avoir au moins **Java 8**.

#### Installation de Java

1. Téléchargez et installez **Java** à partir de [Oracle](https://www.oracle.com/java/technologies/javase-jdk11-downloads.html) ou utilisez un gestionnaire de packages si vous êtes sur Linux.
   
   Pour vérifier si Java est installé, ouvrez un terminal ou une invite de commandes et tapez :
   ```bash
   java -version
   ```
### Installation de JavaFX

2. Téléchargez JavaFX depuis le site officiel de JavaFX.

    Suivez les instructions d'installation pour votre système d'exploitation.

## Cloner le dépôt

### Clonez ce dépôt pour obtenir les fichiers du projet.

```bash
git clone https://github.com/votreusername/latice.git
cd latice
```

## Compilation et exécution

### Compilation : 
    Utilisez Maven ou Gradle pour compiler le projet. Assurez-vous que JavaFX est bien configuré dans votre environnement de développement.

### Avec Maven :

```bash
mvn clean install
```

### Exécution : 
Une fois compilé, vous pouvez exécuter l'application en utilisant la commande suivante :

```bash
mvn javafx:run
```

Si vous n’utilisez pas Maven, vous pouvez exécuter l'application directement depuis votre IDE après avoir configuré le projet avec les dépendances nécessaires (JavaFX).

## Utilisation

### Lancer le jeu : 
Une fois le jeu lancé, vous verrez une interface graphique où vous pouvez interagir avec les objets physiques.

### Contrôles :
Déplacer les objets : Cliquez et faites glisser un objet pour le déplacer.

Appliquer des forces : Utilisez les outils dans l'interface pour appliquer des forces (gravité, poussée, etc.).

Résolution de niveaux : Résolvez les puzzles physiques en utilisant les objets disponibles et les forces appliquées.

### Options du jeu : 
Vous pouvez accéder aux options du jeu via le menu principal pour ajuster les paramètres de simulation (par exemple, la vitesse de la simulation, la taille des objets, etc.).

## Technologies utilisées

    Java 8+ : Le langage de programmation principal.

    JavaFX : Utilisé pour la création de l'interface graphique et la gestion des événements.

    Maven : Outil de gestion de dépendances et de construction du projet.

    Physique 2D : Simulation physique basée sur les principes de la mécanique classique.

## Contribuer

Les contributions sont les bienvenues ! Si vous souhaitez contribuer à l'amélioration de Latice, voici comment vous pouvez procéder :

    Fork le projet.

    Créez une branche pour votre fonctionnalité (git checkout -b feature-nouvelle-fonctionnalité).

    Commitez vos changements (git commit -am 'Ajoute une nouvelle fonctionnalité').

    Poussez votre branche (git push origin feature-nouvelle-fonctionnalité).
    
    Ouvrez une Pull Request.

## License

Ce projet est sous licence MIT. Consultez le fichier LICENSE pour plus d'informations.